"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const subscription_1 = require("../models/subscription");
const NeDB = require("nedb");
const array_1 = require("../helpers/array");
class InMemorySubscriptionRepository {
    constructor(fileName) {
        if (!fileName || !InMemorySubscriptionRepository.database) {
            InMemorySubscriptionRepository.database = new NeDB({
                autoload: true,
                filename: fileName,
            });
        }
    }
    delete(key, channel, endpoint) {
        return new Promise((resolve, reject) => {
            InMemorySubscriptionRepository.database.remove({ key, channel, 'subscription.endpoint': endpoint }, (error, document) => {
                resolve();
            });
        });
    }
    find(key, channel, endpoint) {
        return new Promise((resolve, reject) => {
            InMemorySubscriptionRepository.database.findOne({ key, channel, 'subscription.endpoint': endpoint }, (error, document) => {
                if (!document) {
                    resolve(null);
                    return;
                }
                resolve(new subscription_1.Subscription(document.subscription.endpoint, document.subscription.expirationTime, document.subscription.keys));
            });
        });
    }
    findAll(key, channel) {
        return new Promise((resolve, reject) => {
            InMemorySubscriptionRepository.database.find({ key, channel }, (error, documents) => {
                resolve(documents.map((document) => new subscription_1.Subscription(document.subscription.endpoint, document.subscription.expirationTime, document.subscription.keys)));
            });
        });
    }
    findChannels(key) {
        return new Promise((resolve, reject) => {
            InMemorySubscriptionRepository.database.find({ key }, (error, documents) => {
                const result = array_1.ArrayHelper.distinct(documents.map((document) => document.channel));
                resolve(result);
            });
        });
    }
    insert(key, channel, subscription) {
        return __awaiter(this, void 0, void 0, function* () {
            InMemorySubscriptionRepository.database.insert({
                channel,
                key,
                subscription,
            });
        });
    }
}
InMemorySubscriptionRepository.database = null;
exports.InMemorySubscriptionRepository = InMemorySubscriptionRepository;
//# sourceMappingURL=in-memory-subscription.js.map