"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("../models/client");
const mongodb = require("mongodb");
class MongoClientRepository {
    constructor(host) {
        this.host = host;
        if (!MongoClientRepository.database) {
            this.initialize();
        }
    }
    close() {
        MongoClientRepository.client.close();
    }
    find(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const document = yield MongoClientRepository.database.findOne({ key });
            if (!document) {
                return null;
            }
            return new client_1.Client(document.id, document.key, document.publicKey, document.privateKey, document.endpoint);
        });
    }
    findById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const document = yield MongoClientRepository.database.findOne({ id });
            if (!document) {
                return null;
            }
            return new client_1.Client(document.id, document.key, document.publicKey, document.privateKey, document.endpoint);
        });
    }
    findByPublicKey(publicKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const document = yield MongoClientRepository.database.findOne({ publicKey });
            if (!document) {
                return null;
            }
            return new client_1.Client(document.id, document.key, document.publicKey, document.privateKey, document.endpoint);
        });
    }
    insert(client) {
        return __awaiter(this, void 0, void 0, function* () {
            yield MongoClientRepository.database.insert(client);
        });
    }
    wait() {
        return new Promise((resolve) => {
            setTimeout(resolve, 1100);
        });
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            MongoClientRepository.client = yield mongodb.connect(this.host, { useNewUrlParser: true });
            const database = MongoClientRepository.client.db('web-push-service');
            MongoClientRepository.database = database.collection('clients');
        });
    }
}
MongoClientRepository.client = null;
MongoClientRepository.database = null;
exports.MongoClientRepository = MongoClientRepository;
//# sourceMappingURL=mongo-client.js.map