"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const subscription_1 = require("../models/subscription");
const mongodb = require("mongodb");
class MongoSubscriptionRepository {
    constructor(host) {
        this.host = host;
        if (!MongoSubscriptionRepository.database) {
            this.initialize();
        }
    }
    close() {
        MongoSubscriptionRepository.client.close();
    }
    delete(key, channel, endpoint) {
        return __awaiter(this, void 0, void 0, function* () {
            yield MongoSubscriptionRepository.database.remove({ key, channel, 'subscription.endpoint': endpoint });
        });
    }
    find(key, channel, endpoint) {
        return __awaiter(this, void 0, void 0, function* () {
            const document = MongoSubscriptionRepository.database.findOne({
                key,
                channel,
                'subscription.endpoint': endpoint,
            });
            return new subscription_1.Subscription(document.subscription.endpoint, document.subscription.expirationTime, {
                auth: document.subscription.keys.auth,
                p256dh: document.subscription.keys.p256dh,
            });
        });
    }
    findAll(key, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            const documents = yield MongoSubscriptionRepository.database.find({ key, channel }).toArray();
            return documents.map((document) => new subscription_1.Subscription(document.subscription.endpoint, document.subscription.expirationTime, {
                auth: document.subscription.keys.auth,
                p256dh: document.subscription.keys.p256dh,
            }));
        });
    }
    findChannels(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const documents = yield MongoSubscriptionRepository.database.aggregate([
                {
                    $match: {
                        key,
                    }
                },
                {
                    $group: {
                        _id: '$channel',
                    }
                }
            ]).toArray();
            return documents.map((document) => document._id);
        });
    }
    insert(key, channel, subscription) {
        return __awaiter(this, void 0, void 0, function* () {
            yield MongoSubscriptionRepository.database.insert({
                channel,
                key,
                subscription,
            });
        });
    }
    wait() {
        return new Promise((resolve) => {
            setTimeout(resolve, 1100);
        });
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            MongoSubscriptionRepository.client = yield mongodb.connect(this.host, { useNewUrlParser: true });
            const database = MongoSubscriptionRepository.client.db('web-push-service');
            MongoSubscriptionRepository.database = database.collection('subcriptions');
        });
    }
}
MongoSubscriptionRepository.client = null;
MongoSubscriptionRepository.database = null;
exports.MongoSubscriptionRepository = MongoSubscriptionRepository;
//# sourceMappingURL=mongo-subscription.js.map