"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const subscription_1 = require("../models/subscription");
const subscription_post_1 = require("../validators/requests/subscription-post");
const subscription_delete_1 = require("../validators/requests/subscription-delete");
class SubscriptionRouter {
    static delete(request, response) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (!subscription_delete_1.SubscriptionDeleteRequestValidator.validateParams(request.params)) {
                    response.status(400).json({
                        message: `Invalid Request Parameters`,
                    });
                    return;
                }
                if (!subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody(request.body)) {
                    response.status(400).json({
                        message: `Invalid Request Body`,
                    });
                    return;
                }
                const channel = request.params['channel'];
                const subscription = request.body;
                const client = request['client'];
                const subscriptionService = request['subscriptionService'];
                yield subscriptionService.delete(client.key, channel, subscription.endpoint);
                response.json('OK');
            }
            catch (error) {
                console.error(error);
                response.status(500).json({
                    message: 'An error occurred'
                });
            }
        });
    }
    static post(request, response) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (!subscription_post_1.SubscriptionPostRequestValidator.validateParams(request.params)) {
                    response.status(400).json({
                        message: `Invalid Request Parameters`,
                    });
                    return;
                }
                if (!subscription_post_1.SubscriptionPostRequestValidator.validateBody(request.body)) {
                    response.status(400).json({
                        message: `Invalid Request Body`,
                    });
                    return;
                }
                const channel = request.params['channel'];
                const subscription = new subscription_1.Subscription(request.body.endpoint, request.body.expirationTime, request.body.keys);
                const client = request['client'];
                const subscriptionService = request['subscriptionService'];
                yield subscriptionService.insert(client.key, channel, subscription);
                response.json('OK');
            }
            catch (error) {
                console.error(error);
                response.status(500).json({
                    message: 'An error occurred'
                });
            }
        });
    }
}
exports.SubscriptionRouter = SubscriptionRouter;
//# sourceMappingURL=subscription.js.map