"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const bodyParser = require("body-parser");
const subscription_1 = require("./routes/subscription");
const push_1 = require("./routes/push");
const cors = require("cors");
const client_1 = require("./routes/client");
const path = require("path");
const yaml = require("js-yaml");
const swaggerUI = require("swagger-ui-express");
const authorization_1 = require("./middleware/authorization");
const fs = require("fs");
const client_2 = require("./services/client");
const push_2 = require("./services/push");
const subscription_2 = require("./services/subscription");
const exphbs = require("express-handlebars");
const prompt_1 = require("./routes/prompt");
function initialize(clientRepository, subscriptionRepository, host) {
    const expressApplication = express();
    expressApplication.use('/api/scripts', express.static(path.join(__dirname, 'libraries')));
    expressApplication.use(cors());
    expressApplication.use(bodyParser.json());
    expressApplication.use((request, response, next) => {
        request['clientRepository'] = clientRepository;
        request['subscriptionRepository'] = subscriptionRepository;
        request['clientService'] = new client_2.ClientService(clientRepository, subscriptionRepository);
        request['pushService'] = new push_2.PushService(subscriptionRepository);
        request['subscriptionService'] = new subscription_2.SubscriptionService(subscriptionRepository);
        request['configuration'] = {
            host,
        };
        next();
    });
    const version1Router = express.Router();
    version1Router.route('/client').post(client_1.ClientRouter.post);
    version1Router.route('/client/channels').get(authorization_1.AuthorizationMiddleware.build(), client_1.ClientRouter.channelsGet);
    version1Router.route('/push/:channel').post(authorization_1.AuthorizationMiddleware.build(), push_1.PushRouter.post);
    version1Router
        .route('/subscription/:channel')
        .delete(authorization_1.AuthorizationMiddleware.build(), subscription_1.SubscriptionRouter.delete)
        .post(authorization_1.AuthorizationMiddleware.build(), subscription_1.SubscriptionRouter.post);
    const swaggerJson = yaml.safeLoad(fs.readFileSync(path.join(__dirname, '..', '..', 'swagger.yml')));
    swaggerJson.host = host;
    version1Router.use('/swagger', swaggerUI.serve, swaggerUI.setup(swaggerJson));
    expressApplication.use('/api/v1', version1Router);
    expressApplication.set('views', path.join(__dirname, '..', '..', 'public'));
    expressApplication.engine('handlebars', exphbs({ layoutsDir: path.join(__dirname, '..', '..', 'public') }));
    expressApplication.set('view engine', 'handlebars');
    expressApplication.route('/prompt/:id').get(prompt_1.PromptRouter.get);
    expressApplication.use((request, response, next) => {
        if (request.url.endsWith('.js')) {
            response.set('Service-Worker-Allowed', '/');
        }
        next();
    });
    expressApplication.use('/static', express.static(path.join(__dirname, '..', '..', 'public')));
    expressApplication.use((request, response, next) => {
        response.redirect('/api/v1/swagger');
    });
    return expressApplication;
}
exports.initialize = initialize;
//# sourceMappingURL=server.js.map