"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("../models/client");
const uuid = require("uuid");
const web_push_1 = require("../helpers/web-push");
class ClientService {
    constructor(clientRepository, subscriptionRepository) {
        this.clientRepository = clientRepository;
        this.subscriptionRepository = subscriptionRepository;
    }
    channels(key) {
        if (!key) {
            throw new Error('Key cannot be null');
        }
        return this.subscriptionRepository.findChannels(key);
    }
    create(endpoint) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!endpoint) {
                throw new Error('Endpoint cannot be null');
            }
            const client = this.generateNewClient(endpoint);
            yield this.clientRepository.insert(client);
            return client;
        });
    }
    find(id) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!id) {
                throw new Error('Id cannot be null');
            }
            const client = yield this.clientRepository.findById(id);
            return client;
        });
    }
    generateNewClient(endpoint) {
        const key = uuid.v4();
        const vapidKeys = web_push_1.WebPushHelper.generateVAPIDKeys();
        const client = new client_1.Client(uuid.v4(), key, vapidKeys.publicKey, vapidKeys.privateKey, endpoint);
        return client;
    }
}
exports.ClientService = ClientService;
//# sourceMappingURL=client.js.map