"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const webpush = require("web-push");
class PushService {
    constructor(subscriptionRepository) {
        this.subscriptionRepository = subscriptionRepository;
    }
    create(client, channel, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!client) {
                throw new Error('Client cannot be null');
            }
            client.validate();
            if (!channel) {
                throw new Error('Channel cannot be null');
            }
            if (!payload) {
                throw new Error('Payload cannot be null');
            }
            const subscriptions = yield this.subscriptionRepository.findAll(client.key, channel);
            for (const subscription of subscriptions) {
                yield this.sendNotification(client, channel, subscription, payload);
            }
        });
    }
    sendNotification(client, channel, subscription, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield webpush.sendNotification(subscription, JSON.stringify(payload), {
                    vapidDetails: {
                        subject: client.endpoint,
                        publicKey: client.publicKey,
                        privateKey: client.privateKey,
                    },
                    TTL: 604800,
                });
            }
            catch (error) {
                if (error.statusCode === 410) {
                    yield this.subscriptionRepository.delete(client.key, channel, subscription.endpoint);
                }
                else {
                    throw error;
                }
            }
        });
    }
}
exports.PushService = PushService;
//# sourceMappingURL=push.js.map