"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const sinon = require("sinon");
const authorization_1 = require("../../src/middleware/authorization");
const client_1 = require("../../src/models/client");
describe('AuthorizationMiddleware', () => {
    describe('#apply', () => {
        it('Should call next given key', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                find: sinon.stub().returns(Promise.resolve(new client_1.Client(null, null, null, null, null))),
                findByPublicKey: sinon.stub().returns(Promise.resolve(null)),
            };
            const fn = authorization_1.AuthorizationMiddleware.build();
            const nextFnSpy = sinon.spy();
            yield fn({ clientRepository: clientRepository, get: sinon.stub().returns('key') }, {}, nextFnSpy);
            chai_1.expect(nextFnSpy.calledOnce).to.be.true;
        }));
        it('Should call next given public key', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                find: sinon.stub().returns(Promise.resolve(null)),
                findByPublicKey: sinon.stub().returns(Promise.resolve(new client_1.Client(null, null, null, null, null))),
            };
            const fn = authorization_1.AuthorizationMiddleware.build();
            const nextFnSpy = sinon.spy();
            yield fn({ clientRepository: clientRepository, get: sinon.stub().returns('publicKey') }, {}, nextFnSpy);
            chai_1.expect(nextFnSpy.calledOnce).to.be.true;
        }));
        it('Should not call next given null authorization header', () => __awaiter(this, void 0, void 0, function* () {
            const fn = authorization_1.AuthorizationMiddleware.build();
            const nextFnSpy = sinon.spy();
            yield fn({ get: sinon.stub().returns(null) }, { status: sinon.stub().returns({ end: sinon.stub() }) }, nextFnSpy);
            chai_1.expect(nextFnSpy.calledOnce).to.be.false;
        }));
        it('Should not call next given key and public key does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                find: sinon.stub().returns(Promise.resolve(null)),
                findByPublicKey: sinon.stub().returns(Promise.resolve(null)),
            };
            const fn = authorization_1.AuthorizationMiddleware.build();
            const nextFnSpy = sinon.spy();
            yield fn({ clientRepository: clientRepository, get: sinon.stub().returns('keyOrPublicKey') }, { status: sinon.stub().returns({ end: sinon.stub() }) }, nextFnSpy);
            chai_1.expect(nextFnSpy.calledOnce).to.be.false;
        }));
    });
});
//# sourceMappingURL=authorization.spec.js.map