"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const in_memory_client_1 = require("../../src/repositories/in-memory-client");
const client_1 = require("../../src/models/client");
describe('InMemoryClientRepository', () => {
    describe('#find', () => {
        it('Should return client', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client(null, 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.find('key');
            chai_1.expect(client).to.be.not.null;
        }));
        it('Should return client with correct properties', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client(null, 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.find('key');
            chai_1.expect(client).to.be.not.null;
            chai_1.expect(client.endpoint).to.be.eq('endpoint');
            chai_1.expect(client.key).to.be.eq('key');
            chai_1.expect(client.privateKey).to.be.eq('privateKey');
            chai_1.expect(client.publicKey).to.be.eq('publicKey');
        }));
        it('Should return null given key does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            const client = yield clientRepository.find('key');
            chai_1.expect(client).to.be.null;
        }));
    });
    describe('#findById', () => {
        it('Should return client', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client('id', 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.findById('id');
            chai_1.expect(client).to.be.not.null;
        }));
        it('Should return client with correct properties', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client('id', 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.findById('id');
            chai_1.expect(client).to.be.not.null;
            chai_1.expect(client.endpoint).to.be.eq('endpoint');
            chai_1.expect(client.key).to.be.eq('key');
            chai_1.expect(client.privateKey).to.be.eq('privateKey');
            chai_1.expect(client.publicKey).to.be.eq('publicKey');
        }));
        it('Should return null given key does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            const client = yield clientRepository.findById('id');
            chai_1.expect(client).to.be.null;
        }));
    });
    describe('#findByPublicKey', () => {
        it('Should return client', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client(null, 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.findByPublicKey('publicKey');
            chai_1.expect(client).to.be.not.null;
        }));
        it('Should return client with correct properties', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            yield clientRepository.insert(new client_1.Client(null, 'key', 'publicKey', 'privateKey', 'endpoint'));
            const client = yield clientRepository.findByPublicKey('publicKey');
            chai_1.expect(client).to.be.not.null;
            chai_1.expect(client.endpoint).to.be.eq('endpoint');
            chai_1.expect(client.key).to.be.eq('key');
            chai_1.expect(client.privateKey).to.be.eq('privateKey');
            chai_1.expect(client.publicKey).to.be.eq('publicKey');
        }));
        it('Should return null given key does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = new in_memory_client_1.InMemoryClientRepository(null);
            const client = yield clientRepository.findByPublicKey('publicKey');
            chai_1.expect(client).to.be.null;
        }));
    });
});
//# sourceMappingURL=in-memory-client.spec.js.map