"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const in_memory_subscription_1 = require("../../src/repositories/in-memory-subscription");
const subscription_1 = require("../../src/models/subscription");
describe('InMemoryClientRepository', () => {
    describe('#delete', () => {
        it('Should delete subscription', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', null, null));
            yield subscriptionRepository.delete('key', 'channel', 'endpoint');
            const result = yield subscriptionRepository.find('key', 'channel', 'endpoint');
            chai_1.expect(result).to.be.null;
        }));
    });
    describe('#find', () => {
        it('Should return subscription', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', null, null));
            const result = yield subscriptionRepository.find('key', 'channel', 'endpoint');
            chai_1.expect(result).to.be.not.null;
        }));
        it('Should return subscription with correct properties', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', 100, { auth: null, p256dh: null }));
            const result = yield subscriptionRepository.find('key', 'channel', 'endpoint');
            chai_1.expect(result).to.be.not.null;
            chai_1.expect(result.endpoint).to.be.eq('endpoint');
            chai_1.expect(result.expirationTime).to.be.eq(100);
            chai_1.expect(result.keys).to.be.not.null;
        }));
        it('Should return null given endpoint does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            const result = yield subscriptionRepository.find('key', 'channel', 'endpoint');
            chai_1.expect(result).to.be.null;
        }));
    });
    describe('#findAll', () => {
        it('Should return subscriptions', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', null, null));
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', null, null));
            yield subscriptionRepository.insert('key', 'channel', new subscription_1.Subscription('endpoint', null, null));
            const result = yield subscriptionRepository.findAll('key', 'channel');
            chai_1.expect(result).to.be.not.null;
            chai_1.expect(result.length).to.be.eq(3);
        }));
    });
    describe('#findChannels', () => {
        it('Should return channels', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = new in_memory_subscription_1.InMemorySubscriptionRepository(null);
            yield subscriptionRepository.insert('key', 'channel1', new subscription_1.Subscription('endpoint', null, null));
            yield subscriptionRepository.insert('key', 'channel2', new subscription_1.Subscription('endpoint', null, null));
            yield subscriptionRepository.insert('key', 'channel3', new subscription_1.Subscription('endpoint', null, null));
            const result = yield subscriptionRepository.findChannels('key');
            chai_1.expect(result).to.be.not.null;
            chai_1.expect(result.length).to.be.eq(3);
        }));
    });
});
//# sourceMappingURL=in-memory-subscription.spec.js.map