"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const client_1 = require("../../src/services/client");
const sinon = require("sinon");
describe('ClientService', () => {
    describe('#channels', () => {
        it('Should call SubscriptionRepository#findChannels', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                findChannels: sinon.spy(),
            };
            const clientService = new client_1.ClientService(null, subscriptionRepository);
            yield clientService.channels('my-key');
            chai_1.expect(subscriptionRepository.findChannels.calledOnce).to.be.true;
        }));
        it('Should call SubscriptionRepository#findChannels with correct parameters', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                findChannels: sinon.spy(),
            };
            const clientService = new client_1.ClientService(null, subscriptionRepository);
            yield clientService.channels('my-key');
            const key = subscriptionRepository.findChannels.args[0][0];
            chai_1.expect(key).to.be.eq('my-key');
        }));
        it('Should throw error given null key', () => __awaiter(this, void 0, void 0, function* () {
            const clientService = new client_1.ClientService(null, null);
            try {
                yield clientService.channels(null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Key cannot be null');
            }
        }));
    });
    describe('#create', () => {
        it('Should call ClientRepository#insert', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                insert: sinon.spy(),
            };
            const clientService = new client_1.ClientService(clientRepository, null);
            yield clientService.create('endpoint');
            chai_1.expect(clientRepository.insert.calledOnce).to.be.true;
        }));
        it('Should call ClientRepository#insert with correct parameters', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                insert: sinon.spy(),
            };
            const clientService = new client_1.ClientService(clientRepository, null);
            yield clientService.create('endpoint');
            const client = clientRepository.insert.args[0][0];
            chai_1.expect(client).to.be.not.null;
            chai_1.expect(client.endpoint).to.be.eq('endpoint');
            chai_1.expect(client.key).to.be.not.null;
            chai_1.expect(client.privateKey).to.be.not.null;
            chai_1.expect(client.publicKey).to.be.not.null;
        }));
        it('Should throw error given null endpoint', () => __awaiter(this, void 0, void 0, function* () {
            const clientService = new client_1.ClientService(null, null);
            try {
                yield clientService.create(null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Endpoint cannot be null');
            }
        }));
    });
    describe('#findById', () => {
        it('Should call ClientRepository#findById', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                findById: sinon.spy(),
            };
            const clientService = new client_1.ClientService(clientRepository, null);
            yield clientService.find('my-id');
            chai_1.expect(clientRepository.findById.calledOnce).to.be.true;
        }));
        it('Should call ClientRepository#findById with correct parameters', () => __awaiter(this, void 0, void 0, function* () {
            const clientRepository = {
                findById: sinon.spy(),
            };
            const clientService = new client_1.ClientService(clientRepository, null);
            yield clientService.find('my-id');
            const key = clientRepository.findById.args[0][0];
            chai_1.expect(key).to.be.eq('my-id');
        }));
        it('Should throw error given null key', () => __awaiter(this, void 0, void 0, function* () {
            const clientService = new client_1.ClientService(null, null);
            try {
                yield clientService.find(null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Id cannot be null');
            }
        }));
    });
});
//# sourceMappingURL=client.spec.js.map