"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const subscription_1 = require("../../src/services/subscription");
const sinon = require("sinon");
const subscription_2 = require("../../src/models/subscription");
describe('SubscriptionService', () => {
    describe('#delete', () => {
        it('Should call SubscriptionRepository#delete', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                delete: sinon.stub(),
                find: sinon
                    .stub()
                    .returns(Promise.resolve(new subscription_2.Subscription('endpoint', 0, { auth: 'auth', p256dh: 'p256dh' }))),
            };
            const subscriptionService = new subscription_1.SubscriptionService(subscriptionRepository);
            yield subscriptionService.delete('key', 'channel', 'endpoint');
            chai_1.expect(subscriptionRepository.delete.calledOnce).to.be.true;
        }));
        it('Should call SubscriptionRepository#delete with correct parameters', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                delete: sinon.stub(),
                find: sinon
                    .stub()
                    .returns(Promise.resolve(new subscription_2.Subscription('endpoint', 0, { auth: 'auth', p256dh: 'p256dh' }))),
            };
            const subscriptionService = new subscription_1.SubscriptionService(subscriptionRepository);
            yield subscriptionService.delete('key', 'channel', 'endpoint');
            const key = subscriptionRepository.delete.args[0][0];
            const channel = subscriptionRepository.delete.args[0][1];
            const endpoint = subscriptionRepository.delete.args[0][2];
            chai_1.expect(key).to.be.eq('key');
            chai_1.expect(channel).to.be.eq('channel');
            chai_1.expect(endpoint).to.be.eq('endpoint');
        }));
        it('Should not call SubscriptionRepository#delete given subscription does not exist', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                delete: sinon.stub(),
                find: sinon.stub().returns(Promise.resolve(null)),
            };
            const subscriptionService = new subscription_1.SubscriptionService(subscriptionRepository);
            yield subscriptionService.delete('key', 'channel', 'endpoint');
            chai_1.expect(subscriptionRepository.delete.notCalled).to.be.true;
        }));
        it('Should throw error given null key', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.delete(null, null, null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Key cannot be null');
            }
        }));
        it('Should throw error given null channel', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.delete('key', null, null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Channel cannot be null');
            }
        }));
        it('Should throw error given null endpoint', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.delete('key', 'channel', null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Endpoint cannot be null');
            }
        }));
    });
    describe('#insert', () => {
        it('Should call SubscriptionRepository#insert', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                insert: sinon.stub(),
                find: sinon.stub().returns(Promise.resolve(null)),
            };
            const subscriptionService = new subscription_1.SubscriptionService(subscriptionRepository);
            yield subscriptionService.insert('key', 'channel', new subscription_2.Subscription('endpoint', 0, {
                auth: 'auth',
                p256dh: 'p256dh',
            }));
            chai_1.expect(subscriptionRepository.insert.calledOnce).to.be.true;
        }));
        it('Should not call SubscriptionRepository#insert given subscription exist', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionRepository = {
                insert: sinon.stub(),
                find: sinon.stub().returns(Promise.resolve(new subscription_2.Subscription(null, null, null))),
            };
            const subscriptionService = new subscription_1.SubscriptionService(subscriptionRepository);
            yield subscriptionService.insert('key', 'channel', new subscription_2.Subscription('endpoint', 0, {
                auth: 'auth',
                p256dh: 'p256dh',
            }));
            chai_1.expect(subscriptionRepository.insert.calledOnce).to.be.false;
        }));
        it('Should throw error given null key', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert(null, null, null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Key cannot be null');
            }
        }));
        it('Should throw error given null channel', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert('key', null, null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Channel cannot be null');
            }
        }));
        it('Should throw error given null subscription', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert('key', 'channel', null);
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Subscription cannot be null');
            }
        }));
        it('Should throw error given subscription with null endpoint', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert('key', 'channel', new subscription_2.Subscription(null, null, null));
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Endpoint cannot be null');
            }
        }));
        it('Should throw error given subscription with undefined expirationTime', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert('key', 'channel', new subscription_2.Subscription('endpoint', undefined, null));
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Expiration Time cannot be undefined');
            }
        }));
        it('Should throw error given subscription with null keys', () => __awaiter(this, void 0, void 0, function* () {
            const subscriptionService = new subscription_1.SubscriptionService(null);
            try {
                yield subscriptionService.insert('key', 'channel', new subscription_2.Subscription('endpoint', 0, null));
                throw new Error('Expected Error');
            }
            catch (error) {
                chai_1.expect(error.message).to.be.eq('Keys cannot be null');
            }
        }));
    });
});
//# sourceMappingURL=subscription.spec.js.map