"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const subscription_delete_1 = require("../../../src/validators/requests/subscription-delete");
describe('SubscriptionDeleteRequestValidator', () => {
    describe('#validateBody', () => {
        it('Should return true', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                expirationTime: 0,
                keys: {
                    auth: 'auth',
                    p256dh: 'p256dh',
                },
            });
            chai_1.expect(result).to.be.true;
        }));
        it('Should return true given null expirationTime', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                expirationTime: null,
                keys: {
                    auth: 'auth',
                    p256dh: 'p256dh',
                },
            });
            chai_1.expect(result).to.be.true;
        }));
        it('Should return false given no endpoint', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                expirationTime: 0,
                keys: {
                    auth: 'auth',
                    p256dh: 'p256dh',
                },
            });
            chai_1.expect(result).to.be.false;
        }));
        it('Should return false given no expirationTime', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                keys: {
                    auth: 'auth',
                    p256dh: 'p256dh',
                },
            });
            chai_1.expect(result).to.be.false;
        }));
        it('Should return false given no keys', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                expirationTime: 0,
            });
            chai_1.expect(result).to.be.false;
        }));
        it('Should return false given no auth in keys', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                expirationTime: 0,
                keys: {
                    p256dh: 'p256dh',
                },
            });
            chai_1.expect(result).to.be.false;
        }));
        it('Should return false given no p256dh in keys', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateBody({
                endpoint: 'endpoint',
                expirationTime: 0,
                keys: {
                    auth: 'auth',
                },
            });
            chai_1.expect(result).to.be.false;
        }));
    });
    describe('#validateParams', () => {
        it('Should return true', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateParams({
                channel: 'channel',
            });
            chai_1.expect(result).to.be.true;
        }));
        it('Should return false given no channel', () => __awaiter(this, void 0, void 0, function* () {
            const result = subscription_delete_1.SubscriptionDeleteRequestValidator.validateParams({});
            chai_1.expect(result).to.be.false;
        }));
    });
});
//# sourceMappingURL=subscription-delete.spec.js.map